# Preksha Square
It takes an integer as an input and prints it square.

## Installation
'''pip install preksha_square'''

## How to use it?
Open terminal and type square and then input the integer

## License

©️ 2024 Preksha Dadoo

This repository is licensed under the MIT license.
See LICENSE for details.